# nohedidnt_py

[![codecov](https://codecov.io/gh/NoHeDidnt/nohedidnt_py/branch/main/graph/badge.svg?token=U0OQI580BA)](https://codecov.io/gh/NoHeDidnt/nohedidnt_py)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)

## [License](./LICENSE)
